@@ -8,6 +8,7 @@ from typing_extensions import Annotated
 from einspect.protocols.delayed_bind import bind_api
 from einspect.structs.deco import struct
 from einspect.structs.py_object import Fields, PyObject, PyVarObject
+from einspect.structs.traits import IsGC
 from einspect.types import ptr
 
 _VT = TypeVar("_VT")
@@ -15,7 +16,7 @@ _VT = TypeVar("_VT")
 
 # noinspection PyPep8Naming
 @struct
-class PyListObject(PyVarObject[list, None, _VT]):
+class PyListObject(PyVarObject[list, None, _VT], IsGC):
     """
     Defines a PyListObject Structure.
 
