@@ -1,5 +1,4 @@
-from einspect.views.view_base import View, VarView, AnyView
-from einspect.views.view_set import SetView
+from einspect.views.view_base import AnyView, VarView, View
 from einspect.views.view_bool import BoolView
 from einspect.views.view_dict import DictView
 from einspect.views.view_float import FloatView
@@ -9,3 +8,20 @@ from einspect.views.view_mapping_proxy import MappingProxyView
 from einspect.views.view_set import SetView
 from einspect.views.view_str import StrView
 from einspect.views.view_tuple import TupleView
+from einspect.views.view_type import TypeView
+
+__all__ = (
+    "AnyView",
+    "VarView",
+    "View",
+    "BoolView",
+    "DictView",
+    "FloatView",
+    "IntView",
+    "ListView",
+    "MappingProxyView",
+    "StrView",
+    "SetView",
+    "TupleView",
+    "TypeView",
+)
